# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/type/interval.proto, google/type/latlng.proto
# plugin: python-betterproto
# This file has been @generated

from dataclasses import dataclass
from datetime import datetime

import betterproto


@dataclass(eq=False, repr=False)
class Interval(betterproto.Message):
  """
  Represents a time interval, encoded as a Timestamp start (inclusive) and a
   Timestamp end (exclusive).

   The start must be less than or equal to the end.
   When the start equals the end, the interval is empty (matches no time).
   When both start and end are unspecified, the interval matches any time.
  """

  start_time: datetime = betterproto.message_field(1)
  """
    Optional. Inclusive start of the interval.
    
     If specified, a Timestamp matching this interval will have to be the same
     or after the start.
    """

  end_time: datetime = betterproto.message_field(2)
  """
    Optional. Exclusive end of the interval.
    
     If specified, a Timestamp matching this interval will have to be before the
     end.
    """


@dataclass(eq=False, repr=False)
class LatLng(betterproto.Message):
  """
  An object that represents a latitude/longitude pair. This is expressed as a
   pair of doubles to represent degrees latitude and degrees longitude. Unless
   specified otherwise, this must conform to the
   <a href="http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf">WGS84
   standard</a>. Values must be within normalized ranges.
  """

  latitude: float = betterproto.double_field(1)
  """The latitude in degrees. It must be in the range [-90.0, +90.0]."""

  longitude: float = betterproto.double_field(2)
  """The longitude in degrees. It must be in the range [-180.0, +180.0]."""
